@@ -247,7 +247,10 @@ class NmfModel:
     def get_m_proxy(self):
         if not self.is_ok():
             self.test_model()
-        return self.get_w() @ self.get_h().T
+        whd = self.get_w() @ self.get_h().T
+        whd.index = self._origina_mat.index
+        whd.columns = self._origin_mat.columns
+        return whd
 
     def get_w_hhi_1(self, do_sort=True):
         if not self.is_ok():
